@@ -4,7 +4,7 @@ use Carp;
 use Finance::Bank::Natwest::CredentialsProvider::Constant;
 
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 =head1 NAME
 
@@ -119,7 +119,7 @@ __END__
 
 =head1 AUTHOR
 
-Jody Belka C<perl-module-fbn@aardvark-ss.com>
+Jody Belka C<knew@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
